LazyInductiveDataset
====================

.. currentmodule:: pykeen.datasets.inductive

.. autoclass:: LazyInductiveDataset
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~LazyInductiveDataset.inductive_inference
      ~LazyInductiveDataset.inductive_testing
      ~LazyInductiveDataset.inductive_validation
      ~LazyInductiveDataset.transductive_training

   .. rubric:: Attributes Documentation

   .. autoattribute:: inductive_inference
   .. autoattribute:: inductive_testing
   .. autoattribute:: inductive_validation
   .. autoattribute:: transductive_training
